From: akpm@linux-foundation.org
To: sukadev@us.ibm.com, ebiederm@xmission.com, menage@google.com,
oleg@tv-sign.ru, xemul@openvz.org, mm-commits@vger.kernel.org
Subject: - pid-namespaces-allow-signalling-container-init.patch removed from -mm tree
Date: Fri, 19 Oct 2007 15:51:54 -0700 [thread overview]
Message-ID: <200710192251.l9JMpsab024221@imap1.linux-foundation.org> (raw)
The patch titled
pid namespaces: allow signalling cgroup-init
has been removed from the -mm tree. Its filename was
pid-namespaces-allow-signalling-container-init.patch
This patch was dropped because it was merged into mainline or a subsystem tree
------------------------------------------------------
Subject: pid namespaces: allow signalling cgroup-init
From: Sukadev Bhattiprolu <sukadev@us.ibm.com>
Only the global-init process must be special - any other cgroup-init
process must be killable to prevent run-away processes in the system.
TODO: Ideally we should allow killing the cgroup-init only from parent
cgroup and prevent it being killed from within the cgroup.
But that is a more complex change and will be addressed by a follow-on
patch. For now allow the cgroup-init to be terminated by any process
with sufficient privileges.
Signed-off-by: Sukadev Bhattiprolu <sukadev@us.ibm.com>
Acked-by: Pavel Emelyanov <xemul@openvz.org>
Cc: Oleg Nesterov <oleg@tv-sign.ru>
Cc: Sukadev Bhattiprolu <sukadev@us.ibm.com>
Cc: Paul Menage <menage@google.com>
Cc: "Eric W. Biederman" <ebiederm@xmission.com>
Signed-off-by: Andrew Morton <akpm@linux-foundation.org>
---
kernel/signal.c | 6 ++----
1 file changed, 2 insertions(+), 4 deletions(-)
diff -puN kernel/signal.c~pid-namespaces-allow-signalling-container-init kernel/signal.c
--- a/kernel/signal.c~pid-namespaces-allow-signalling-container-init
+++ a/kernel/signal.c
@@ -1835,11 +1835,9 @@ relock:
continue;
/*
* Init of a pid space gets no signals it doesn't want from
* within that pid space. It can of course get signals from
* its parent pid space.
*/
- if (current == task_child_reaper(current))
+ if (is_global_init(current))
continue;
if (sig_kernel_stop(signr)) {
_
Patches currently in -mm which might be from sukadev@us.ibm.com are
origin.patch
reply other threads:[~2007-10-19 23:11 UTC|newest]
Thread overview: [no followups] expand[flat|nested] mbox.gz Atom feed
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=200710192251.l9JMpsab024221@imap1.linux-foundation.org \
--to=akpm@linux-foundation.org \
--cc=ebiederm@xmission.com \
--cc=linux-kernel@vger.kernel.org \
--cc=menage@google.com \
--cc=mm-commits@vger.kernel.org \
--cc=oleg@tv-sign.ru \
--cc=sukadev@us.ibm.com \
--cc=xemul@openvz.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -1835,11 +1835,9 @@ relock:
continue;
/*
- * Init of a pid space gets no signals it doesn't want from
- * within that pid space. It can of course get signals from
- * its parent pid space.
+ * Global init gets no signals it doesn't want.
*/
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.